#recent test, removed hadley devtools install

### load required libraries and source code ##############

#in the near future, all the functions below and data (data not related to the esets) used in this analysis will be available in a package called metaGx.
#the packages functions and data can be found in our github repo (https://github.com/bhklab/MetaGx/tree/MetaGx2017). Of course, whatever is needed
#for the analysis can be found in this capsule

#file_sources <- list.files(path = 'W:/Projekte/Pancalyze/Felix/R/MetaGxPanc/code/metaGx/R/', pattern = '*.R')
#sapply(paste0('W:/Projekte/Pancalyze/Felix/R/MetaGxPanc/code/metaGx/R/',file_sources), source, .GlobalEnv)



library(SummarizedExperiment)
library("easyGgplot2")
library(lava)
library(BiocInstaller)
library(survcomp)
library(matrixStats)
library(lattice)
library(rasterVis)
library(metafor)
library(gplots)
library(mclust)
library(ConsensusClusterPlus)
library(xtable)
library(raster)
library(gdata)
library(tidyverse)
library(survival)
library(survminer)


# WENN WAS NICHT GEHT:
#if (!requireNamespace("BiocManager", quietly = TRUE))
#  install.packages("BiocManager")
#
#BiocManager::install("org.Hs.eg.db")


setwd("W:/Projekte/Pancalyze/Felix/Programmieren/R/MetaGxPanc/code")

file_sources <- list.files(path = './metaGx/R/', pattern = '*.R')
sapply(paste0('./metaGx/R/',file_sources), source, .GlobalEnv)

#' Function to group patients according to their risk predictions
#'
#' This function groups patients by splitting their risk predictions/scores into a number of equally sized groups according to the number of groups specified by the user. The grouping is most commonly performed in order to conduct survival analyses on the patients
#' @param survInfo One of the data frames in the list returned from the function getPatientSurvivalData. Alternatively, a data frame with 5 columns called eventTime, eventStatus, scoreVals, scoreVals, numGenesPresent, and dataName that correspond to
#' the survival event times, the survival event's status, the score/risk prediction of the patient, the number of genes used to calculate the score and the name of the dataset that the patient is from. 
#' @param numGroups an integer specifying the number of groups the patients will be split into when generating survival curves and calculating the log rank p value. The value is 2 by default and cannot exceed 5.
#' @param normalizeEsetScores A boolean specifying whether the groups used to determine the log rank p value should be determined by 1. Splitting the scores/risk predictions of the patients from each dataset into the number of groups specified or
#' 2. normalizing the scores of the patients in each dataset such that the 2.5 percentile and 97.5 percentile for the patients scores in each dataset have the same value, then creating one vector of patient score and splitting this
#' vector of patient score sinto the number of groups specified (TRUE). Normalization/TRUE is the default.
#' @return a vector the length of the number of patients in the survInfo data frame that has the group (integer) that each patient is part of
#' @export
#' @examples
#' 
#' geneEntrezIds = c("43847", "434768", "80070", "3620")
#' geneDirecs = c(1, 1, -1, -1)
#' survInfoList = getPatientSurvivalData(geneEntrezIds, geneDirecs, cancerType = "ovarian", subtype = "verhaak", survivalMetric = "overall")
#' patientGroups = groupPatientsViaScores(survInfo = survInfoList$`All Patients`, numGroups = 2, normalizeEsetScores = TRUE)

groupPatientsViaScoresFX2 = function(survInfo, numGroups)
{
  
  dataGroups = c()
  
  scoreVals = survInfo$scoreVals
  
  sortInd = sort(scoreVals, decreasing = TRUE, index.return=TRUE)$ix;
 
  groupSize = floor(length(scoreVals)/numGroups)
  remainder =  length(scoreVals) - groupSize*numGroups
  dataGroups = matrix(0, length(scoreVals))
  extra = 0
  
  for(i in 0:(numGroups - 1))
  {
    startInd = 1 + i*groupSize - extra
    if((numGroups - i) == remainder)
    {
      groupSize = groupSize + 1
      extra = i
    }
    endInd = (i + 1)*groupSize - extra
    dataGroups[sortInd[startInd:endInd]] = i;
  } 

  return(dataGroups)
}



#' Function to group patients according to their risk predictions
#'
#' This function groups patients by splitting their risk predictions/scores into a number of equally sized groups according to the number of groups specified by the user. The grouping is most commonly performed in order to conduct survival analyses on the patients
#' @param survInfo One of the data frames in the list returned from the function getPatientSurvivalData. Alternatively, a data frame with 5 columns called eventTime, eventStatus, scoreVals, scoreVals, numGenesPresent, and dataName that correspond to
#' the survival event times, the survival event's status, the score/risk prediction of the patient, the number of genes used to calculate the score and the name of the dataset that the patient is from. 
#' @param numGroups an integer specifying the number of groups the patients will be split into when generating survival curves and calculating the log rank p value. The value is 2 by default and cannot exceed 5.
#' @param normalizeEsetScores A boolean specifying whether the groups used to determine the log rank p value should be determined by 1. Splitting the scores/risk predictions of the patients from each dataset into the number of groups specified or
#' 2. normalizing the scores of the patients in each dataset such that the 2.5 percentile and 97.5 percentile for the patients scores in each dataset have the same value, then creating one vector of patient score and splitting this
#' vector of patient score sinto the number of groups specified (TRUE). Normalization/TRUE is the default.
#' @return a vector the length of the number of patients in the survInfo data frame that has the group (integer) that each patient is part of
#' @export
#' @examples
#' 
#' geneEntrezIds = c("43847", "434768", "80070", "3620")
#' geneDirecs = c(1, 1, -1, -1)
#' survInfoList = getPatientSurvivalData(geneEntrezIds, geneDirecs, cancerType = "ovarian", subtype = "verhaak", survivalMetric = "overall")
#' patientGroups = groupPatientsViaScores(survInfo = survInfoList$`All Patients`, numGroups = 2, normalizeEsetScores = TRUE)

groupPatientsViaScoresFx = function(survInfo, percentile)
{
  
  # die 2.5 Percentile ist bei -1, die 97,5 bei + 1. Die 25er Percentile ist nach Dreisatz dann bei -0.4736842105
  
  percentilScore = -0.4736842105  # 25 er
  percentilScore = -0.7894736842  # 10 er
  percentilScore = 0  # 50 er
  percentilScore =  -1 + (percentil-2.5)*2/95
  
  dataGroups = c()
  
  
  for(i in 1:length(survInfo$scoreVals))
  {
    dataGroups[i] = ifelse(survInfo$scoreVals[i] <= percentilScore, 1, 0)
  }
  return(dataGroups)
}





#if the fast variable is TRUE, then some of the objects that are time consuming to create are not created. Instead, they are
#loaded into the capsule after being saved in a previous run with fastBool = FALSE. If you would like the capsule to create 
#everything from scratch use fast = FALSE. This was done for rapid prototyping but included as it may be of interest to users
#who do not want to wait many hours to generate all the results and instead would like ~40 minute run time
fastBool = TRUE

##### define some (two) functions used in the analysis ##########################



######################## load datasets ####################################

#library(MetaGxOvarian)
#library(MetaGxBreast)
library(MetaGxPancreas)

#because the datasets are large and loading them exceeds the network limits for the codeOcean 
#the data has been stored as an object and loaded in. Use the below commented out lines
#to load in the exact same data via the packages
setExperimentHubOption("CACHE", "W:/Projekte/Pancalyze/Felix/R/MetaGxPanc/data/ExperimentHubData")

#dataListOvSe = dataListOv = get(load("W:/Projekte/Pancalyze/Felix/R/MetaGxPanc/data/dataListOvSe.Rdata"))
#dataListAndDups = loadOvarianDatasets(removeDuplicates = FALSE)
#dataListOv = dataListAndDups$esets

#dataListPancAll = loadPancreasDatasets(removeDuplicates = FALSE, removeSeqSubset = FALSE)
#dataListPancAll = dataListPancAll$esets

#dataListAndDups = loadBreastDatasets(removeDuplicates = FALSE)
#dataListTcgaMetaAndDups = loadBreastDatasets(loadString = c("TCGA", "METABRIC"), removeDuplicates = FALSE)
#dataListBr = c(dataListAndDups$esets, dataListTcgaMetaAndDups$esets)

#dataListBrSe = dataListBr = get(load("W:/Projekte/Pancalyze/Felix/R/MetaGxPanc/data/dataListBrSe.Rdata"))
dataListPancAll = get(load("W:/Projekte/Pancalyze/Felix/Programmieren/R/MetaGxPanc/data/dataListPancSe.Rdata"))



########Get the best probes for the datasets based on IQR ############


######## PANCREAS ANALYSIS ################
moffittClassifier = get(load("W:/Projekte/Pancalyze/Felix/Programmieren/R/MetaGxPanc/data/moffittClassifier.RData"))

esets = dataListPancAll
#these patients are in ICGCMICRO so remove the subset
esets$ICGCSEQ = NULL
bestProbes = lapply(esets, function(x) rowData(x)$best_probe)
pancreasEnts = unique(as.character(unlist(lapply(1:length(esets), function(x) rowData(esets[[x]])$EntrezGene.ID[bestProbes[[x]]]))))
expFrameList = lapply(1:length(esets), function(x) assay(esets[[x]])[bestProbes[[x]], ])
entList = lapply(1:length(esets), function(x) as.character(rowData(esets[[x]])$EntrezGene.ID[bestProbes[[x]]]))
subtypeName = NULL
censorTime = 10

#obtain survival event info (status and time) for patients 
esetsEventsAndTimes = getSurvEventData(esets, "overall")


#shift the expression values so the 2.5 percentile is -1 and 97.5 percentile is +1
#for the expression values of a given gene in all the datasets.
#store shifted expression data and survival info in lists
print("standardize expression data")
newLow = -1
newHigh = 1
survVitals = survTimes = list()
for(i in 1:length(expFrameList))
{
  print(i)
  #this shift actually has not effect on the hazard ratios since it is a linear transform,
  #thus with or without it the resulting signature will be the same
  expFrame = expFrameList[[i]]
  for(j in 1:nrow(expFrame))
  {
    quantVals = quantile(expFrame[j, ], c(.025, .975), na.rm = TRUE)
    oldLow = quantVals[1]
    oldHigh = quantVals[2]
    expFrame[j, ] = newLow*(1 - (expFrame[j, ] - oldLow)/(oldHigh - oldLow)) + newHigh*((expFrame[j, ] - oldLow)/(oldHigh - oldLow))
  }
  
  #remove patients that do not have either the survival status or survival time available
  remCols = c(which(is.na(esetsEventsAndTimes$eventList[[i]])), which(is.na(esetsEventsAndTimes$eventTimeList[[i]])))
  if(length(remCols) > 0)
  {
    expFrame = expFrame[, -remCols]
    survVitals[[i]] = esetsEventsAndTimes$eventList[[i]][-remCols]
    survTimes[[i]] = esetsEventsAndTimes$eventTimeList[[i]][-remCols]
  }else{
    survVitals[[i]] = esetsEventsAndTimes$eventList[[i]]
    survTimes[[i]] = esetsEventsAndTimes$eventTimeList[[i]]
  }
  
  expFrameList[[i]] = expFrame
}

#get the hazzard ratios for all the genes in each dataset

  

  
#results from this analysis agree with those from the metaGx package for each dataset
#i.e getGenesProgValue for a gene gives same D.index as found above 

load("W:/Projekte/Pancalyze/Felix/Programmieren/R/MetaGxPanc/data/dIndsListPancSe.RData")


datasetsWithSurvData = c("CHEN", "COLLISON", "ICGCMICRO", "KIRBY", "OUH", "PCSI", "TCGA", "UNC", "WINTER", "ZHANG", "YANG")
dataListPanc = dataListPancAll[datasetsWithSurvData]
esetsAndProbesPanc = getEsetsProbesSubtypesEvents(cancerType = "pancreas", subtype = "moffitt", survivalMetric = "overall", dataNames = NULL, includeAll = FALSE, dataList = dataListPanc)



# ----------------------------------- IDO1


topSixGenes = c()
topSixGenes[1] = "IDO1"


#rerun top 6 to get one object
geneSigListPanc = sapply(topSixGenes, function(x) list(x))
geneDirecListPanc = sapply(topSixGenes, function(x) list(1))

topGenesPanc = getGenesProgValue(geneSigListPanc, geneDirecListPanc, cancerType = "pancreas", subtype = "moffitt", survivalMetric = "overall", addBenchmarks = FALSE, genesRequired = 0, esetsAndProbes = esetsAndProbesPanc)


# manchmal muss man 12 mal dev.off() machen .... bis null device kommt

dev.off()


# -----------------------------------
#
# 3 berlebenskurven nach
# https://www.bioconductor.org/packages/release/bioc/vignettes/survcomp/inst/doc/survcomp.pdf
# und
# https://www.bioconductor.org/packages/release/bioc/vignettes/survcomp/inst/doc/survcomp.R
#
#

surv.time.all <- topGenesPanc$patientSurvData$IDO1$`All Patients`$timeToDeath
surv.event.all <- topGenesPanc$patientSurvData$IDO1$`All Patients`$vitalStat
aurka.exprs <- topGenesPanc$patientSurvData$IDO1$`All Patients`$scoreVals
aurka.exprs.length <- as.vector(table(topGenesPanc$patientSurvData$IDO1$`All Patients`$dataName))

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.33, 0.66), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1

  qq <- factor(x=qq, levels=0:1)

  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$IDO1$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("IDO1 Low   ", "IDO1 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)


# -------- IDO 15th Percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq, probs=c(0.15, 0.15), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$IDO1$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("IDO1 Low   ", "IDO1 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)

# -------- IDO 33th Percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq, probs=c(0.33, 0.33), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$IDO1$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("IDO1 Low   ", "IDO1 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)



# -------- IDO 66th Percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq, probs=c(0.66, 0.66), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$IDO1$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("IDO1 Low   ", "IDO1 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)




# ----------------------------------- LAG3


topSixGenes = c()
topSixGenes[1] = "LAG3"


#rerun top 6 to get one object
geneSigListPanc = sapply(topSixGenes, function(x) list(x))
geneDirecListPanc = sapply(topSixGenes, function(x) list(1))

topGenesPanc = getGenesProgValue(geneSigListPanc, geneDirecListPanc, cancerType = "pancreas", subtype = "moffitt", survivalMetric = "overall", addBenchmarks = FALSE, genesRequired = 0, esetsAndProbes = esetsAndProbesPanc)


# manchmal muss man 12 mal dev.off() machen .... bis null device kommt

dev.off()


# -----------------------------------
#
# 3 berlebenskurven nach
# https://www.bioconductor.org/packages/release/bioc/vignettes/survcomp/inst/doc/survcomp.pdf
# und
# https://www.bioconductor.org/packages/release/bioc/vignettes/survcomp/inst/doc/survcomp.R
#
#

surv.time.all <- topGenesPanc$patientSurvData$LAG3$`All Patients`$timeToDeath
surv.event.all <- topGenesPanc$patientSurvData$LAG3$`All Patients`$vitalStat
aurka.exprs <- topGenesPanc$patientSurvData$LAG3$`All Patients`$scoreVals
aurka.exprs.length <- as.vector(table(topGenesPanc$patientSurvData$LAG3$`All Patients`$dataName))

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.33, 0.66), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$LAG3$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("LAG3 Low   ", "LAG3 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)

# ----- LAG3 15th percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.15, 0.15), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$LAG3$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("LAG3 Low   ", "LAG3 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)

# ----- LAG3 33th percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.33, 0.33), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$LAG3$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("LAG3 Low   ", "LAG3 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)

# ----- LAG3 66th percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.66, 0.66), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$LAG3$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("LAG3 Low   ", "LAG3 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)


# ----------------------------------- HAVCR2 = TIM3


topSixGenes = c()
topSixGenes[1] = "HAVCR2"


#rerun top 6 to get one object
geneSigListPanc = sapply(topSixGenes, function(x) list(x))
geneDirecListPanc = sapply(topSixGenes, function(x) list(1))

topGenesPanc = getGenesProgValue(geneSigListPanc, geneDirecListPanc, cancerType = "pancreas", subtype = "moffitt", survivalMetric = "overall", addBenchmarks = FALSE, genesRequired = 0, esetsAndProbes = esetsAndProbesPanc)


# manchmal muss man 12 mal dev.off() machen .... bis null device kommt

dev.off()


# -----------------------------------
#
# 3 berlebenskurven nach
# https://www.bioconductor.org/packages/release/bioc/vignettes/survcomp/inst/doc/survcomp.pdf
# und
# https://www.bioconductor.org/packages/release/bioc/vignettes/survcomp/inst/doc/survcomp.R
#
#

surv.time.all <- topGenesPanc$patientSurvData$HAVCR2$`All Patients`$timeToDeath
surv.event.all <- topGenesPanc$patientSurvData$HAVCR2$`All Patients`$vitalStat
aurka.exprs <- topGenesPanc$patientSurvData$HAVCR2$`All Patients`$scoreVals
aurka.exprs.length <- as.vector(table(topGenesPanc$patientSurvData$HAVCR2$`All Patients`$dataName))

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.33, 0.66), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$HAVCR2$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("HAVCR2 Low   ", "HAVCR2 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)

# ------- TIM3 15th Percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.15, 0.15), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$HAVCR2$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("HAVCR2 Low   ", "HAVCR2 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)


# ------- TIM3 33th Percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.33, 0.33), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$HAVCR2$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("HAVCR2 Low   ", "HAVCR2 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)


# ------- TIM3 66th Percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.66, 0.66), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$HAVCR2$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("HAVCR2 Low   ", "HAVCR2 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)



# ----------------------------------- VSIR = VISTA


topSixGenes = c()

topSixGenes[1] = "VSIR"

#rerun top 6 to get one object
geneSigListPanc = sapply(topSixGenes, function(x) list(x))
geneDirecListPanc = sapply(topSixGenes, function(x) list(1))

topGenesPanc = getGenesProgValue(geneSigListPanc, geneDirecListPanc, cancerType = "pancreas", subtype = "moffitt", survivalMetric = "overall", addBenchmarks = FALSE, genesRequired = 0, esetsAndProbes = esetsAndProbesPanc)



# manchmal muss man 12 mal dev.off() machen .... bis null device kommt

dev.off()


# -----------------------------------
#
# 3 berlebenskurven nach
# https://www.bioconductor.org/packages/release/bioc/vignettes/survcomp/inst/doc/survcomp.pdf
# und
# https://www.bioconductor.org/packages/release/bioc/vignettes/survcomp/inst/doc/survcomp.R
#
#

surv.time.all <- topGenesPanc$patientSurvData$VSIR$`All Patients`$timeToDeath
surv.event.all <- topGenesPanc$patientSurvData$VSIR$`All Patients`$vitalStat
aurka.exprs <- topGenesPanc$patientSurvData$VSIR$`All Patients`$scoreVals
aurka.exprs.length <- as.vector(table(topGenesPanc$patientSurvData$VSIR$`All Patients`$dataName))

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.33, 0.66), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$VSIR$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("VSIR Low   ", "VSIR High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)


# ---- VISTA 15th Percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.15, 0.15), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$VSIR$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("VSIR Low   ", "VSIR High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)

# ---- VISTA 33th Percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.33, 0.33), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$VSIR$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("VSIR Low   ", "VSIR High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)

# ---- VISTA 66th Percentile

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.66, 0.66), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$VSIR$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("VSIR Low   ", "VSIR High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)


# ----------------------------------- HAVCR2 = TIM3 & Galectn 9


topSixGenes = c()
topSixGenes[1] = "LGALS9"
topSixGenes[2] = "HAVCR2"

#rerun top 6 to get one object
geneSigListPanc = sapply(topSixGenes, function(x) list(x))
geneDirecListPanc = sapply(topSixGenes, function(x) list(1))

topGenesPanc = getGenesProgValue(geneSigListPanc, geneDirecListPanc, cancerType = "pancreas", subtype = "moffitt", survivalMetric = "overall", addBenchmarks = FALSE, genesRequired = 0, esetsAndProbes = esetsAndProbesPanc)


# manchmal muss man 12 mal dev.off() machen .... bis null device kommt

dev.off()


# ----------------------------------- Galectin 9 einfach
#
# 3 berlebenskurven nach
# https://www.bioconductor.org/packages/release/bioc/vignettes/survcomp/inst/doc/survcomp.pdf
# und
# https://www.bioconductor.org/packages/release/bioc/vignettes/survcomp/inst/doc/survcomp.R
#
#

surv.time.all <- topGenesPanc$patientSurvData$LGALS9$`All Patients`$timeToDeath
surv.event.all <- topGenesPanc$patientSurvData$LGALS9$`All Patients`$vitalStat
aurka.exprs <- topGenesPanc$patientSurvData$LGALS9$`All Patients`$scoreVals
aurka.exprs.length <- as.vector(table(topGenesPanc$patientSurvData$LGALS9$`All Patients`$dataName))

tc <- 10  # 10-Jahresberleben reicht

pos <- 0
mygroup <- NULL
myquants <- NULL

for(i in aurka.exprs.length){
  qq <- aurka.exprs[(pos+1):(pos+i)]
  # myq <- quantile(qq, probs=0.187, na.rm=TRUE) Signifikant
  myq <- quantile(qq,probs=c(0.33, 0.66), na.rm=TRUE)
  qq[aurka.exprs[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[aurka.exprs[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup <- c(mygroup,qq)
  
  myquants <- c(myquants, myq)
  pos <- pos + i
}

bb = survdiff(Surv(surv.time.all, surv.event.all) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=surv.time.all, surv.event=surv.event.all, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- topGenesPanc$patientSurvData$LGALS9$`All Patients`$dataName

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("LGALS9 Low   ", "LGALS9 High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)



# ------ Galectin 9 und TIM3 DOPPELT 


surv.time.all <- topGenesPanc$patientSurvData$LGALS9$`All Patients`$timeToDeath
surv.event.all <- topGenesPanc$patientSurvData$LGALS9$`All Patients`$vitalStat
aurka.exprs <- topGenesPanc$patientSurvData$LGALS9$`All Patients`$scoreVals
aurka.exprs.length <- as.vector(table(topGenesPanc$patientSurvData$LGALS9$`All Patients`$dataName))



a <- topGenesPanc$patientSurvData$HAVCR2$`All Patients`
b <- topGenesPanc$patientSurvData$LGALS9$`All Patients`
c <- inner_join(a,b, by="Patient ID")

c <- c %>% mutate(dataName.x = factor(dataName.x))
c <- c %>% mutate(dataName.y = factor(dataName.y))


 # must be true
identical(factor(c$dataName.x), c$dataName.y)

tc <- 10  # 10-Jahresberleben reicht


mygroup1 <- NULL
mygroup2 <- NULL
myquants1 <- NULL
myquants2 <- NULL

# hier muss noch nachgedacht werden
probs = c(0.33, 0.66)
probs = c(0.33, 0.33)
probs = c(0.66, 0.66)
#probs = c(0.80, 0.80)

pos <- 0
for(i in as.vector(table(c$dataName.x))) {
  qq <- c$scoreVals.x[(pos+1):(pos+i)]
  myq <- quantile(qq,probs, na.rm=TRUE)
  qq[c$scoreVals.x[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[c$scoreVals.x[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup1 <- c(mygroup1,qq)
  
  myquants1 <- c(myquants1, myq)
  pos <- pos + i
}


pos <- 0
for(i in as.vector(table(c$dataName.x))) {
  qq <- c$scoreVals.y[(pos+1):(pos+i)]
  myq <- quantile(qq,probs, na.rm=TRUE)
  qq[c$scoreVals.y[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[c$scoreVals.y[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup2 <- c(mygroup2,qq)
  
  myquants2 <- c(myquants2, myq)
  pos <- pos + i
}

mygroup <- ifelse(mygroup1 == 2 & mygroup2 == 2, 2, 1)



identical(c$timeToDeath.x, c$timeToDeath.y)
identical(c$vitalStat.x, c$vitalStat.y)

bb = survdiff(Surv(c$timeToDeath.x, c$vitalStat.x) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=c$timeToDeath.x, surv.event=c$vitalStat.x, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- c$dataName.x

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("other   ", "both High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)



# ----------------------------------- PD1 und PD1L -------------------------------------------------------------------------------------------------


topSixGenes = c()
topSixGenes[1] = "PDCD1"
topSixGenes[2] = "CD274"

#rerun top 6 to get one object
geneSigListPanc = sapply(topSixGenes, function(x) list(x))
geneDirecListPanc = sapply(topSixGenes, function(x) list(1))

topGenesPanc = getGenesProgValue(geneSigListPanc, geneDirecListPanc, cancerType = "pancreas", subtype = "moffitt", survivalMetric = "overall", addBenchmarks = FALSE, genesRequired = 0, esetsAndProbes = esetsAndProbesPanc)


# manchmal muss man 12 mal dev.off() machen .... bis null device kommt

dev.off()


a <- topGenesPanc$patientSurvData$HAVCR2$`All Patients`
b <- topGenesPanc$patientSurvData$LGALS9$`All Patients`
c <- inner_join(a,b, by="Patient ID")

c <- c %>% mutate(dataName.x = factor(dataName.x))
c <- c %>% mutate(dataName.y = factor(dataName.y))


# must be true
identical(factor(c$dataName.x), c$dataName.y)

tc <- 10  # 10-Jahresberleben reicht


mygroup1 <- NULL
mygroup2 <- NULL
myquants1 <- NULL
myquants2 <- NULL

# hier muss noch nachgedacht werden
probs = c(0.33, 0.66)
probs = c(0.33, 0.33)
probs = c(0.66, 0.66)
#probs = c(0.80, 0.80)

pos <- 0
for(i in as.vector(table(c$dataName.x))) {
  qq <- c$scoreVals.x[(pos+1):(pos+i)]
  myq <- quantile(qq,probs, na.rm=TRUE)
  qq[c$scoreVals.x[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[c$scoreVals.x[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup1 <- c(mygroup1,qq)
  
  myquants1 <- c(myquants1, myq)
  pos <- pos + i
}


pos <- 0
for(i in as.vector(table(c$dataName.x))) {
  qq <- c$scoreVals.y[(pos+1):(pos+i)]
  myq <- quantile(qq,probs, na.rm=TRUE)
  qq[c$scoreVals.y[(pos+1):(pos+i)] < myq[1]] <- 0
  qq[c$scoreVals.y[(pos+1):(pos+i)] >= myq[2]] <- 1
  
  qq <- factor(x=qq, levels=0:1)
  
  mygroup2 <- c(mygroup2,qq)
  
  myquants2 <- c(myquants2, myq)
  pos <- pos + i
}

mygroup <- ifelse(mygroup1 == 2 & mygroup2 == 2, 2, 1)



identical(c$timeToDeath.x, c$timeToDeath.y)
identical(c$vitalStat.x, c$vitalStat.y)

bb = survdiff(Surv(c$timeToDeath.x, c$vitalStat.x) ~ mygroup, rho=0)
logRankP = (1 - pchisq(bb$chisq, 1))
if(logRankP == 0) logRankP = 1.1*10^(-16)

surv.data <- censor.time(surv.time=c$timeToDeath.x, surv.event=c$vitalStat.x, time.cens=tc)
dd <- data.frame("time"=surv.data[[1]], "event"=surv.data[[2]], "gg"=mygroup)
gg <- c$dataName.x

dev.off()
plot.new()

km.coxph.plot(formula.s=formula(Surv(time, event) ~ gg), data.s=dd, x.label="Time (years)", y.label="Survival", main.title="", sub.title="", leg.text=c("other   ", "both High   "), leg.pos="topright", leg.bty = "n", leg.inset=0.05,  o.text = "", .col=c("black", "darkgrey"), .lty=c(1,1), show.n.risk=TRUE, n.risk.step=1, n.risk.cex=0.85, verbose=FALSE)
text(1.6, 0.08, paste("p = ", format(logRankP, scientific =  FALSE, digits = 3)), cex = 0.9, font = 1)

